//------------------------------------------------------------------------
//      GT-511
//-------------------------------------------------------------------------
#include "GT511.h" //     
#include "uart.h" //     

//        GT-511Cx  
volatile extern unsigned int tx_Command;       //       

//     UART
//        UART 
//   OK 
int SendCommand(unsigned char pPkt[])
{  
   unsigned int i = 0;
   
   for (i = 0; i < SB_OEM_PKT_SIZE; i++)
      {
      UART1tx_byte(pPkt[i]);     //    UART1
      }
   return OK;
}  


//   ()   
//   
unsigned long CalcChkSumOfCmdAckPkt(unsigned char pPkt[])
{
      unsigned long wChkSum = 0;
      unsigned char *pBuf = (unsigned char*)pPkt;
      unsigned int i;
	
	for(i=0;i<(SB_OEM_PKT_SIZE - SB_OEM_CHK_SUM_SIZE);i++)
           {	
           wChkSum += pBuf[i];
           }
     return  wChkSum;
}
 

//    
//  OK          
//          
int CheckChkSumOfRpsAckPkt(unsigned char pPkt[])
{
	unsigned short wChkSum = 0;
	unsigned char *pBuf = (unsigned char*)pPkt;
	int i;

	if(pPkt[0] != RESPONSE_START_CODE1 || pPkt[1] != RESPONSE_START_CODE2)
		return PKT_HDR_ERR;

	if(pPkt[2] != DEVICE_ID || pPkt[3] != ZERO)
		return PKT_DEV_ID_ERR;

	for(i=0;i<(SB_OEM_PKT_SIZE - SB_OEM_CHK_SUM_SIZE);i++)
		wChkSum += pBuf[i];
       
	if(pPkt[10] != (wChkSum & 0xFF) || pPkt[11] != (wChkSum & 0xFF00)>>8)
		return PKT_CHK_SUM_ERR;

	return OK;
}


//"" ( ) 
//       ACK 
//Flag = 0  -        
//Flag != 0  -        
int Open(unsigned char pPkt[], unsigned int Flag)
{
	int rtn = 0;
	unsigned long tmp = 0;

	/*********Open Command***********/
	pPkt[0] = COMMAND_START_CODE1;
	pPkt[1] = COMMAND_START_CODE2;
	pPkt[2] = DEVICE_ID;
	pPkt[3] = DEVICE_ID>>8;
	pPkt[4] = Flag & 0xFF;
	pPkt[5] = (Flag & 0xFF00) >> 8 ;
	pPkt[6] = (Flag & 0xFF0000) >> 16;
	pPkt[7] = (Flag & 0xFF000000) >> 24;
	pPkt[8] = OPEN;               //     
	pPkt[9] = ZERO;               //------------- 
        tmp = CalcChkSumOfCmdAckPkt(pPkt);  //   
	pPkt[10] = tmp % 256;  //    
	pPkt[11] = tmp >> 8;   //---------------------------------
	/*********Open Command***********/
                
        rtn = SendCommand(pPkt);  //      UART    
        tx_Command = ON; //        
        
        return rtn;
}


//""  
//   ,         
//       ACK 
int Termination(unsigned char pPkt[])
{
	int rtn = 0;
	unsigned long tmp = 0;

	/*********Termination Command***********/
	pPkt[0] = COMMAND_START_CODE1;
	pPkt[1] = COMMAND_START_CODE2;
	pPkt[2] = DEVICE_ID;
	pPkt[3] = DEVICE_ID>>8;
	pPkt[4] = ZERO;
	pPkt[5] = ZERO;
	pPkt[6] = ZERO;
	pPkt[7] = ZERO;
	pPkt[8] = CLOSE;            //   
	pPkt[9] = ZERO;             //------------- 
	tmp = CalcChkSumOfCmdAckPkt(pPkt);  //   
	pPkt[10] = tmp % 256;    //    
	pPkt[11] = tmp >> 8;     //---------------------------------
	/*********Open Command***********/
         
        rtn = SendCommand(pPkt);  //      UART    
        tx_Command = ON; //        
        
        return rtn;
}


//   
//       ACK 
//State = 0   -   () 
//State != 0   -   ()  
int LED(unsigned char pPkt[], unsigned int State)
{
        int rtn = 0;
	unsigned long tmp = 0;

	/*********LED Command***********/
	pPkt[0] = COMMAND_START_CODE1;
	pPkt[1] = COMMAND_START_CODE2;
	pPkt[2] = DEVICE_ID;
	pPkt[3] = DEVICE_ID>>8;
	pPkt[4] = State & 0xFF;
	pPkt[5] = (State & 0xFF00) >> 8 ;
	pPkt[6] = (State & 0xFF0000) >> 16;
	pPkt[7] = (State & 0xFF000000) >> 24;
	pPkt[8] = CMOSLED;             //     
	pPkt[9] = ZERO;                //------------- 
        tmp = CalcChkSumOfCmdAckPkt(pPkt);  //   
	pPkt[10] = tmp % 256;  //    
	pPkt[11] = tmp >> 8;   //---------------------------------
	/*********LED Command***********/
                
        rtn = SendCommand(pPkt);  //      UART    
        tx_Command = ON; //        
                
        return rtn;  
}

//,      
//       ACK 
//     (  ACK)    0,     
//     (  ACK)     0,       
int RemoveFinger(unsigned char pPkt[]) 
{
	int rtn = 0;
	unsigned long tmp = 0;
   
	/*********Check finger pressing status Command***********/
	pPkt[0] = COMMAND_START_CODE1;
	pPkt[1] = COMMAND_START_CODE2;
	pPkt[2] = DEVICE_ID;
	pPkt[3] = DEVICE_ID>>8;
	pPkt[4] = ZERO;
	pPkt[5] = ZERO;
	pPkt[6] = ZERO;
	pPkt[7] = ZERO;
	pPkt[8] = ISPRESSFINGER;        //     
	pPkt[9] = ZERO;                 //-------------
	tmp = CalcChkSumOfCmdAckPkt(pPkt);  //   
	pPkt[10] = tmp % 256;   //    
	pPkt[11] = tmp >> 8;    //--------------------------------- 
        /*********Check finger pressing status Command***********/
	
	rtn = SendCommand(pPkt);  //      UART    
        tx_Command = ON; //        

        return rtn;
}


//     
//        NACK,       .
//        ACK,      
//    .   ACK   RAM    
//      .
// cFlag = 0  -    ,      () ,  
//    
// cFlag != 0  -     
//          
//( )
int CaptureFinger(unsigned char pPkt[], unsigned int cFlag)
{
	int rtn = 0;
	unsigned long tmp = 0;
     
	/*********CaptureFinger Command***********/
	pPkt[0] = COMMAND_START_CODE1;
	pPkt[1] = COMMAND_START_CODE2;
	pPkt[2] = DEVICE_ID;
	pPkt[3] = DEVICE_ID>>8;
	pPkt[4] = cFlag & 0xFF;
	pPkt[5] = (cFlag & 0xFF00) >> 8 ;
	pPkt[6] = (cFlag & 0xFF0000) >> 16;
	pPkt[7] = (cFlag & 0xFF000000) >> 24;
	pPkt[8] = CAPTURE_FINGER;       //   
	pPkt[9] = ZERO;                 //-------------    
	tmp = CalcChkSumOfCmdAckPkt(pPkt); //   
	pPkt[10] = tmp % 256;  //     
	pPkt[11] = tmp >> 8;   //--------------------------------- 
	/*********CaptureFinger Command***********/

	rtn = SendCommand(pPkt);  //      UART    
        tx_Command = ON; //        
        
        return rtn;
}


//     
//       ACK 
//     (  ACK)       
//   
int GetEnrollCount(unsigned char pPkt[]) 
{
	int rtn = 0;
	unsigned long tmp = 0;
        
	/*********GetEnrollCount Command***********/
	pPkt[0] = COMMAND_START_CODE1;
	pPkt[1] = COMMAND_START_CODE2;
	pPkt[2] = DEVICE_ID;
	pPkt[3] = DEVICE_ID>>8;
	pPkt[4] = ZERO;
	pPkt[5] = ZERO;
	pPkt[6] = ZERO;
	pPkt[7] = ZERO;
	pPkt[8] = GETENROLLCOUNT;    //   
	pPkt[9] = ZERO;              //-------------  
	tmp = CalcChkSumOfCmdAckPkt(pPkt); //   
	pPkt[10] = tmp % 256;    //    
	pPkt[11] = tmp >> 8;     //---------------------------------
	/*********GetEnrollCount Command***********/
        
        rtn = SendCommand(pPkt);  //      UART    
        tx_Command = ON; //        
        
        return rtn;
}


//,          
//       ACK,      
//       NACK,        
//ID  -   ,     ,        
int CheckEnroll(unsigned char pPkt[], int ID)
{
	int rtn = 0;
	unsigned long tmp = 0;

	/*********CheckEnroll Command***********/
	pPkt[0] = COMMAND_START_CODE1;
	pPkt[1] = COMMAND_START_CODE2;
	pPkt[2] = DEVICE_ID;
	pPkt[3] = DEVICE_ID>>8;
	pPkt[4] = ID & 0xFF;
	pPkt[5] = (ID & 0xFF00) >> 8 ;
	pPkt[6] = (ID & 0xFF0000) >> 16;
	pPkt[7] = (ID & 0xFF000000) >> 24;
	pPkt[8] = CHECKENROLLED;    //  
	pPkt[9] = ZERO;             //-------------
	tmp = CalcChkSumOfCmdAckPkt(pPkt);  //   
	pPkt[10] = tmp % 256;       //    
	pPkt[11] = tmp >> 8;        //--------------------------------- 
	/*********CheckEnroll Command***********/

	rtn = SendCommand(pPkt);  //      UART    
        tx_Command = ON; //        
        
        return rtn;
}


//  ()        (1:N)  
//       ACK,    
//     (  ACK)       
//      ,  
//            
int Identify(unsigned char pPkt[])
{
	int rtn = 0;
	unsigned long tmp = 0;

	/*********Identify Command***********/
	pPkt[0] = COMMAND_START_CODE1;
	pPkt[1] = COMMAND_START_CODE2;
	pPkt[2] = DEVICE_ID;
	pPkt[3] = DEVICE_ID>>8;
	pPkt[4] = ZERO;
	pPkt[5] = ZERO;
	pPkt[6] = ZERO;
	pPkt[7] = ZERO;
	pPkt[8] = IDENTIFY;       //  
	pPkt[9] = ZERO;           //------------- 
	tmp = CalcChkSumOfCmdAckPkt(pPkt);  //   
	pPkt[10] = tmp % 256;         //    
	pPkt[11] = tmp >> 8;          //---------------------------------
	/*********Identify Command***********/

	rtn = SendCommand(pPkt);  //      UART    
        tx_Command = ON; //        
        
        return rtn;
}


// ( )         (1:1)  
//ID  -     ,   ,        
//       ACK,    ( )
//  NACK,    ( ) 
//            
int Verify(unsigned char pPkt[], int ID)
{
	int rtn = 0;
	unsigned long tmp = 0;

	/*********Verify Command***********/
	pPkt[0] = COMMAND_START_CODE1;
	pPkt[1] = COMMAND_START_CODE2;
	pPkt[2] = DEVICE_ID;
	pPkt[3] = DEVICE_ID>>8;
        pPkt[4] = ID & 0xFF;
	pPkt[5] = (ID & 0xFF00) >> 8 ;
	pPkt[6] = (ID & 0xFF0000) >> 16;
	pPkt[7] = (ID & 0xFF000000) >> 24;
	pPkt[8] = VERIFY;          //  
	pPkt[9] = ZERO;            //-------------  
	tmp = CalcChkSumOfCmdAckPkt(pPkt);  //    
	pPkt[10] = tmp % 256;     //     
	pPkt[11] = tmp >> 8;      //--------------------------------- 
	/*********Verify Command***********/
        
        rtn = SendCommand(pPkt);  //      UART    
        tx_Command = ON; //        
        
        return rtn;
}

